==> 1.0.0.tar.gz: example/lib/page_push_inbox.dart <==
import 'package:flutter/material.dart';
import 'package:netmera_flutter_sdk/Netmera.dart';
import 'package:netmera_flutter_sdk/NetmeraInboxFilter.dart';
import 'package:netmera_flutter_sdk/NetmeraPushInbox.dart';
///
/// Copyright (c) 2019 Inomera Research.
/// Author Burak Soykal
///
class PushInboxPage extends StatefulWidget {
  @override
  _PushInboxPageState createState() => _PushInboxPageState();
}
class _PushInboxPageState extends State<PushInboxPage> {
  String _currentStatus = Netmera.PUSH_OBJECT_STATUS_ALL.toString();
  String _count = "0";
  List<Widget> _inbox = List();
  List<NetmeraPushInbox> _pushInboxList = List();
  List<DropdownMenuItem<String>> getInboxList() {
    List<DropdownMenuItem<String>> items = new List();
    items.add(new DropdownMenuItem(value: Netmera.PUSH_OBJECT_STATUS_ALL.toString(), child: new Text("ALL")));
    items.add(new DropdownMenuItem(value: Netmera.PUSH_OBJECT_STATUS_READ.toString(), child: new Text("READ")));
    items.add(new DropdownMenuItem(value: Netmera.PUSH_OBJECT_STATUS_UNREAD.toString(), child: new Text("UNREAD")));
    items.add(new DropdownMenuItem(value: Netmera.PUSH_OBJECT_STATUS_DELETED.toString(), child: new Text("DELETED")));
    return items;
  }
  onInboxStatusChanged(String status) {
    setState(() {
      _currentStatus = status;
    });
  }
  clearInboxList() {
    setState(() {
      _inbox.clear();
    });
  }
  String getStatusText(int status) {
    switch (status) {
      case Netmera.PUSH_OBJECT_STATUS_ALL:
        return "ALL";
        break;
      case Netmera.PUSH_OBJECT_STATUS_READ:
        return "READ";
        break;
      case Netmera.PUSH_OBJECT_STATUS_UNREAD:
        return "UNREAD";
        break;
      case Netmera.PUSH_OBJECT_STATUS_DELETED:
        return "DELETED";
        break;
    }
    return "";
  }
  fillInboxList(list) {
    _pushInboxList = list;
  }
  // Click Functions
  emptyAction() {}
  getInboxFilter() {
    NetmeraInboxFilter inboxFilter = new NetmeraInboxFilter();
    inboxFilter.setPageSize(2);
    inboxFilter.setStatus(int.parse(_currentStatus));
    inboxFilter.setIncludeExpiredObjects(true);
    inboxFilter.setCategories(null);
    return inboxFilter;
  }
  fetchInbox() async {
    clearInboxList();
    Netmera.fetchInbox(getInboxFilter()).then((list) {
      fillInboxList(list);
    });
  }
  fetchNextPage() async {
    Netmera.fetchNextPage().then((list) {
      if (list.isNotEmpty) {
        clearInboxList();
      }
      fillInboxList(list);
    });
  }
  countForStatus() async {
    Netmera.countForStatus(int.parse(_currentStatus)).then((val) {
      setState(() {
        if (val != -1) {
          _count = val.toString();
        }
      });
    });
  }
  handlePushObject() async {
    if (_pushInboxList.isNotEmpty) {
      Netmera.handlePushObject(_pushInboxList[0].getPushId());
    }
  }
  inboxUpdateStatus() {
    List<String> selectedPushList = List();
    if (_pushInboxList.length > 1) {
      selectedPushList.add(_pushInboxList[0].getPushId());
      selectedPushList.add(_pushInboxList[1].getPushId());
    }
    int status = Netmera.PUSH_OBJECT_STATUS_UNREAD;
    Netmera.inboxUpdateStatus(selectedPushList, status);
  }
  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: EdgeInsets.only(top: 1.0),
      child: Column(
        children: [
          Padding(
            padding: EdgeInsets.only(left: 16.0, right: 16.0, top: 16.0, bottom: 5.0),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              mainAxisSize: MainAxisSize.max,
              children: [
                new Expanded(
                  child: IntrinsicHeight(
                    child: new DropdownButton(
                      value: _currentStatus,
                      items: getInboxList(),
                      onChanged: onInboxStatusChanged,
                    ),
                  ),
                ),
                new Expanded(
                  child: IntrinsicHeight(
                    child: RaisedButton(
                      child: Text('Fetch Inbox'),
                      onPressed: fetchInbox,
                    ),
                  ),
                ),
                new Expanded(
                  child: IntrinsicHeight(
                    child: RaisedButton(
                      child: Text('Fetch Next Page'),
                      onPressed: fetchNextPage,
                    ),
                  ),
                ),
              ],
            ),
          ),
          Padding(
            padding: EdgeInsets.only(left: 16.0, right: 16.0),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceEvenly,
              mainAxisSize: MainAxisSize.max,
              children: [
                Expanded(
                  child: new IntrinsicHeight(
                    child: RaisedButton(
                      child: Text('Count For Status'),
                      onPressed: countForStatus,
                    ),
                  ),
                ),
                Expanded(
                  child: new IntrinsicHeight(
                    child: RaisedButton(
                      child: Text('Handle Push Object'),
                      onPressed: handlePushObject,
                    ),
                  ),
                ),
                Expanded(
                  child: new IntrinsicHeight(
                    child: RaisedButton(
                      child: Text('Update Status(Unread 2 elem.)'),
                      onPressed: inboxUpdateStatus,
                    ),
                  ),
                ),
              ],
            ),
          ),
          Text(
            "Count For Status:" + _count,
            textAlign: TextAlign.left,
            style: TextStyle(fontWeight: FontWeight.bold),
          ),
          Expanded(
            child: _pushInboxListView(context),
          ),
        ],
      ),
    );
  }
  Widget _pushInboxListView(BuildContext context) {
    return ListView.separated(
      itemCount: _pushInboxList.length,
      itemBuilder: (context, index) {
        if(index>=_pushInboxList.length) return null;
        final inboxItem = _pushInboxList[index];
        return new Padding(
          padding: EdgeInsets.all(10.0),
          child: Column(crossAxisAlignment: CrossAxisAlignment.stretch, children: [
            Text('Title: ' + (inboxItem.getTitle() == null ? "null" : inboxItem.getTitle())),
            Text('Subtitle: ' + (inboxItem.getSubtitle() == null ? "null" : inboxItem.getSubtitle())),
            Text('Body: ' + (inboxItem.getBody() == null ? "null" : inboxItem.getBody())),
            Text('Push Type: ' + inboxItem.getPushType().toString()),
            Text('Push Id: ' + (inboxItem.getPushId() == null ? "null" : inboxItem.getPushId())),
            Text('Push Instance Id: ' +
                (inboxItem.getPushInstanceId() == null ? "null" : inboxItem.getPushInstanceId())),
            Text('Send Date: ' + (inboxItem.getSendDate() == null ? "null" : inboxItem.getSendDate())),
            Text('Inbox Status: ' + inboxItem.getInboxStatus().toString()),
            Text('Action Deeplink Url: ' + (inboxItem.getDeepLink() == null ? "null" : inboxItem.getDeepLink())),
            Text('Action Web Page Url: ' + (inboxItem.getWebPage() == null ? "null" : inboxItem.getWebPage())),
            Text('External Id: ' + (inboxItem.getExternalId() == null ? "null" : inboxItem.getExternalId())),
            Text('Media Attachment Url: ' +
                (inboxItem.getMediaAttachmentUrl() == null ? "null" : inboxItem.getMediaAttachmentUrl())),
            Text('Categories: ' + (inboxItem.getCategories() == null ? "null" : inboxItem.getCategories().toString())),
            Text('Custom Json: ' + (inboxItem.getCustomJson() == null ? "null" : inboxItem.getCustomJson().toString())),
            Row(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Text('Carousel: '),
                inboxItem.getCarousel() == null
                    ? Text("null")
                    : Expanded(
                  child: _carouselList(inboxItem.getCarousel()),
                )
              ],
            )
          ]),
        );
      },
      separatorBuilder: (context, index) {
        return Divider();
      },
    );
  }
  Widget _carouselList(List carousel) {
    return ListView.separated(
      shrinkWrap: true,
      itemCount: carousel.length,
      itemBuilder: (context, index) {
        final carouselItem = carousel[index];
        return new Padding(
          padding: EdgeInsets.all(10.0),
          child: Column(crossAxisAlignment: CrossAxisAlignment.stretch, children: [
            Text('id: ' + (carouselItem["id"] == null ? "null" : carouselItem["id"])),
            Text('bpp: ' + (carouselItem["bpp"] == null ? "null" : carouselItem["bpp"])),
            Text('ctext: ' + (carouselItem["ctext"] == null ? "null" : carouselItem["ctext"])),
            Text('ctitle: ' + (carouselItem["ctitle"] == null ? "null" : carouselItem["ctitle"])),
          ]),
        );
      },
      separatorBuilder: (context, index) {
        return Divider();
      },
    );
  }
}

==> 1.0.1.tar.gz: example/lib/page_push_inbox.dart <==
import 'package:flutter/material.dart';
import 'package:netmera_flutter_sdk/Netmera.dart';
import 'package:netmera_flutter_sdk/NetmeraInboxFilter.dart';
import 'package:netmera_flutter_sdk/NetmeraPushInbox.dart';

///
/// Copyright (c) 2019 Inomera Research.
/// Author Burak Soykal
///
class PushInboxPage extends StatefulWidget {
  @override
  _PushInboxPageState createState() => _PushInboxPageState();
}

class _PushInboxPageState extends State<PushInboxPage> {
  String _currentStatus = Netmera.PUSH_OBJECT_STATUS_ALL.toString();
  String _count = "0";
  List<Widget> _inbox = List();
  List<NetmeraPushInbox> _pushInboxList = List();

  List<DropdownMenuItem<String>> getInboxList() {
    List<DropdownMenuItem<String>> items = new List();
    items.add(new DropdownMenuItem(value: Netmera.PUSH_OBJECT_STATUS_ALL.toString(), child: new Text("ALL")));
    items.add(new DropdownMenuItem(value: Netmera.PUSH_OBJECT_STATUS_READ.toString(), child: new Text("READ")));
    items.add(new DropdownMenuItem(value: Netmera.PUSH_OBJECT_STATUS_UNREAD.toString(), child: new Text("UNREAD")));
    items.add(new DropdownMenuItem(value: Netmera.PUSH_OBJECT_STATUS_DELETED.toString(), child: new Text("DELETED")));
    return items;
  }

  onInboxStatusChanged(String status) {
    setState(() {
      _currentStatus = status;
    });
  }

  clearInboxList() {
    setState(() {
      _inbox.clear();
    });
  }

  String getStatusText(int status) {
    switch (status) {
      case Netmera.PUSH_OBJECT_STATUS_ALL:
        return "ALL";
        break;
      case Netmera.PUSH_OBJECT_STATUS_READ:
        return "READ";
        break;
      case Netmera.PUSH_OBJECT_STATUS_UNREAD:
        return "UNREAD";
        break;
      case Netmera.PUSH_OBJECT_STATUS_DELETED:
        return "DELETED";
        break;
    }
    return "";
  }

  fillInboxList(list) {
    setState(() {
      _pushInboxList = list;
    });
  }

  // Click Functions
  emptyAction() {}

  getInboxFilter() {
    NetmeraInboxFilter inboxFilter = new NetmeraInboxFilter();
    inboxFilter.setPageSize(2);
    inboxFilter.setStatus(int.parse(_currentStatus));
    inboxFilter.setIncludeExpiredObjects(true);
    inboxFilter.setCategories(null);
    return inboxFilter;
  }

  fetchInbox() async {
    clearInboxList();
    Netmera.fetchInbox(getInboxFilter()).then((list) {
      fillInboxList(list);
    }).catchError((error) {
      print(error);
    });
  }

  fetchNextPage() async {
    Netmera.fetchNextPage().then((list) {
      if (list.isNotEmpty) {
        clearInboxList();
      }
      fillInboxList(list);
    }).catchError((error) {
      print(error);
    });
  }

  countForStatus() async {
    Netmera.countForStatus(int.parse(_currentStatus)).then((val) {
      setState(() {
        if (val != -1) {
          _count = val.toString();
        }
      });
    });
  }

  handlePushObject() async {
    if (_pushInboxList.isNotEmpty) {
      Netmera.handlePushObject(_pushInboxList[0].getPushId());
    }
  }

  handleInteractiveAction() async {
    if (_pushInboxList.isNotEmpty) {
      _pushInboxList.forEach((element) {
        if (element.getInteractiveActions() != null && element.getInteractiveActions().isNotEmpty) {
          Netmera.handleInteractiveAction(element.getInteractiveActions()[0]);
          return;
        }
      });
    }
  }

  inboxUpdateStatus() {
    List<String> selectedPushList = List();
    if (_pushInboxList.length > 1) {
      selectedPushList.add(_pushInboxList[0].getPushId());
      selectedPushList.add(_pushInboxList[1].getPushId());
    }
    int status = Netmera.PUSH_OBJECT_STATUS_UNREAD;
    Netmera.inboxUpdateStatus(selectedPushList, status).then((netmeraError) {
      if (netmeraError != null) {
        print(netmeraError);
      }
    }).catchError((error) {
      print(error);
    });
  }

  updateAll() async {
    if (_pushInboxList.isNotEmpty) {
      var updateStatus = int.parse(_currentStatus);
      if(updateStatus == Netmera.PUSH_OBJECT_STATUS_ALL) {
        print("Please select different status than all!!");
        return;
      }

        Netmera.updateAll(updateStatus).then((netmeraError) {
          fetchInbox();
        }).catchError((error) {
          print(error);
        });
      }
  }

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: EdgeInsets.only(top: 1.0),
      child: Column(
        children: [
          Padding(
            padding: EdgeInsets.only(left: 16.0, right: 16.0, top: 16.0, bottom: 5.0),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              mainAxisSize: MainAxisSize.max,
              children: [
                new Expanded(
                  child: IntrinsicHeight(
                    child: new DropdownButton(
                      value: _currentStatus,
                      items: getInboxList(),
                      onChanged: onInboxStatusChanged,
                    ),
                  ),
                ),
                new Expanded(
                  child: IntrinsicHeight(
                    child: RaisedButton(
                      child: Text('Fetch Inbox'),
                      onPressed: fetchInbox,
                    ),
                  ),
                ),
                new Expanded(
                  child: IntrinsicHeight(
                    child: RaisedButton(
                      child: Text('Fetch Next Page'),
                      onPressed: fetchNextPage,
                    ),
                  ),
                ),
              ],
            ),
          ),
          Padding(
            padding: EdgeInsets.only(left: 16.0, right: 16.0, bottom: 5.0),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceEvenly,
              mainAxisSize: MainAxisSize.max,
              children: [
                Expanded(
                  child: new IntrinsicHeight(
                    child: RaisedButton(
                      child: Text('Update All'),
                      onPressed: updateAll,
                    ),
                  ),
                ),
                Expanded(
                  child: new IntrinsicHeight(
                    child: RaisedButton(
                      child: Text('Update Status(Unread 2 elem.)'),
                      onPressed: inboxUpdateStatus,
                    ),
                  ),
                ),
              ],
            ),
          ),
          Padding(
            padding: EdgeInsets.only(left: 16.0, right: 16.0),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceEvenly,
              mainAxisSize: MainAxisSize.max,
              children: [
                Expanded(
                  child: new IntrinsicHeight(
                    child: RaisedButton(
                      child: Text('Count For Status'),
                      onPressed: countForStatus,
                    ),
                  ),
                ),
                Expanded(
                  child: new IntrinsicHeight(
                    child: RaisedButton(
                      child: Text('Handle Push Object'),
                      onPressed: handlePushObject,
                    ),
                  ),
                ),
                Expanded(
                  child: new IntrinsicHeight(
                    child: RaisedButton(
                      child: Text('Handle Interactive Action'),
                      onPressed: handleInteractiveAction,
                    ),
                  ),
                ),
              ],
            ),
          ),
          Text(
            "Count For Status:" + _count,
            textAlign: TextAlign.left,
            style: TextStyle(fontWeight: FontWeight.bold),
          ),
          Expanded(
            child: _pushInboxListView(context),
          ),
        ],
      ),
    );
  }

  Widget _pushInboxListView(BuildContext context) {
    return ListView.separated(
      itemCount: _pushInboxList.length,
      itemBuilder: (context, index) {
        if (index >= _pushInboxList.length) return null;
        final inboxItem = _pushInboxList[index];
        return new Padding(
          padding: EdgeInsets.all(10.0),
          child: Column(crossAxisAlignment: CrossAxisAlignment.stretch, children: [
            Text('Title: ' + (inboxItem.getTitle() == null ? "null" : inboxItem.getTitle())),
            Text('Subtitle: ' + (inboxItem.getSubtitle() == null ? "null" : inboxItem.getSubtitle())),
            Text('Body: ' + (inboxItem.getBody() == null ? "null" : inboxItem.getBody())),
            Text('Push Type: ' + inboxItem.getPushType().toString()),
            Text('Push Id: ' + (inboxItem.getPushId() == null ? "null" : inboxItem.getPushId())),
            Text('Push Instance Id: ' +
                (inboxItem.getPushInstanceId() == null ? "null" : inboxItem.getPushInstanceId())),
            Text('Send Date: ' + (inboxItem.getSendDate() == null ? "null" : inboxItem.getSendDate())),
            Text('Inbox Status: ' + inboxItem.getInboxStatus().toString()),
            Text('Action Deeplink Url: ' + (inboxItem.getDeepLink() == null ? "null" : inboxItem.getDeepLink())),
            Text('Action Web Page Url: ' + (inboxItem.getWebPage() == null ? "null" : inboxItem.getWebPage())),
            Text('External Id: ' + (inboxItem.getExternalId() == null ? "null" : inboxItem.getExternalId())),
            Text('Media Attachment Url: ' +
                (inboxItem.getMediaAttachmentUrl() == null ? "null" : inboxItem.getMediaAttachmentUrl())),
            Text('Categories: ' + (inboxItem.getCategories() == null ? "null" : inboxItem.getCategories().toString())),
            Text('Custom Json: ' + (inboxItem.getCustomJson() == null ? "null" : inboxItem.getCustomJson().toString())),
            Row(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Text('Carousel: '),
                inboxItem.getCarousel() == null
                    ? Text("null")
                    : Expanded(
                        child: _carouselList(inboxItem.getCarousel()),
                      )
              ],
            )
          ]),
        );
      },
      separatorBuilder: (context, index) {
        return Divider();
      },
    );
  }

  Widget _carouselList(List carousel) {
    return ListView.separated(
      shrinkWrap: true,
      itemCount: carousel.length,
      itemBuilder: (context, index) {
        final carouselItem = carousel[index];
        return new Padding(
          padding: EdgeInsets.all(10.0),
          child: Column(crossAxisAlignment: CrossAxisAlignment.stretch, children: [
            Text('id: ' + (carouselItem["id"] == null ? "null" : carouselItem["id"])),
            Text('bpp: ' + (carouselItem["bpp"] == null ? "null" : carouselItem["bpp"])),
            Text('ctext: ' + (carouselItem["ctext"] == null ? "null" : carouselItem["ctext"])),
            Text('ctitle: ' + (carouselItem["ctitle"] == null ? "null" : carouselItem["ctitle"])),
          ]),
        );
      },
      separatorBuilder: (context, index) {
        return Divider();
      },
    );
  }
}
